@@ -13,7 +13,7 @@ use base qw(Exporter);
 
 BEGIN {
     @Time::TAI::Simple::EXPORT = qw(tai tai10 tai35);
-    $Time::TAI::Simple::VERSION = '1.04';
+    $Time::TAI::Simple::VERSION = '1.05';
 }
 
 our @LEAPSECOND_UNIX_PATHNAME_LIST = (
@@ -245,7 +245,7 @@ sub _leapseconds_filename {
 
     $seconds_since_epoch = tai();
     $since_epoch_minus_ten = tai10();  # Probably what you want!
-    $same_as_utc_time_for_now = tai35();
+    $close_to_utc_time_for_now = tai35();
 
     # You can likely skip the rest of this synopsis.
 
@@ -277,7 +277,7 @@ sub _leapseconds_filename {
     $seconds_since_epoch = $tai00->time();
 
     $tai35 = Time::TAI::Simple->new(mode => 'tai35');
-    $same_as_utc_time_for_now = $tai35->time();
+    $close_to_utc_time_for_now = $tai35->time();
 
     # reduce processing overhead of instantiation, at the expense of
     # some precision, by turning off fine-tuning step:
@@ -336,9 +336,9 @@ and by the TAI patch currently proposed to the standard zoneinfo implementation.
 When most people use TAI time, it is usually TAI-10.
 
 B<tai35> provides TAI-35 seconds, which makes it exactly equal to the system
-clock time returned by C<Time::HiRes::time()> at the time of this writing.
-When the IETF next introduces a leapsecond, B<tai35> will be one second ahead
-of the system clock time.
+clock time returned by C<Time::HiRes::time()> before July 1 2015.
+As the IETF introduces more leapseconds, B<tai35> will be one second ahead
+of the system clock time with each introduction.
 
 This mode is provided for use-cases where compatability with other TAI time
 implementations is not required, and keeping the monotonically increasing time
